@@ -10,14 +10,12 @@
 #'
 calcDefCapital = function(trades,EAD, reg_data, effective_maturity)
 {
-  R_bII  = 0.12*(1-exp(-50*reg_data$PD))/(1-exp(-50))+0.24*(1-(1-exp(-50*reg_data$PD))/(1-exp(-50)))
+  R_bII  = 0.12*(1-exp(-50*reg_data$PD_cpty))/(1-exp(-50))+0.24*(1-(1-exp(-50*reg_data$PD_cpty))/(1-exp(-50)))
   R_stressed = 1.25*R_bII
-  b = (0.11852-0.05478*log(reg_data$PD))^2
-  K = (pnorm((qnorm(reg_data$PD)/sqrt(1-R_stressed) + sqrt(R_stressed/(1-R_stressed))*qnorm(0.999)))-reg_data$PD)*(1+(effective_maturity-2.5)*b)/(1-1.5*b)
+  b = (0.11852-0.05478*log(reg_data$PD_cpty))^2
+  K = (pnorm((qnorm(reg_data$PD_cpty)/sqrt(1-R_stressed) + sqrt(R_stressed/(1-R_stressed))*qnorm(0.999)))-reg_data$PD_cpty)*(1+(effective_maturity-2.5)*b)/(1-1.5*b)
 
-  RWA = 12.5*K*EAD
-
-  default_capital_charge = 0.08*reg_data$LGD*RWA
+  default_capital_charge = 0.08*reg_data$LGD*K*EAD
 
   return(default_capital_charge)
 }
